<?php
/**
 * This class simply puts HTML code / JavaScript code or CSS code out to the
 * browser
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebOutput extends BaseFrameworkSystem implements OutputStreamer, Registerable {
	/**
	 * The instance for the singleton design pattern
	 */
	private static $webInstance = null;

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Create a new web output system and set the content type
	 *
	 * @param	$applicationInstance	An instance of a ManageableApplication class
	 * @return	$debugInstance			An instance of this middleware class
	 */
	public final static function createWebOutput (ManageableApplication $applicationInstance) {
		// Is there no instance?
		if (is_null(self::$webInstance)) {
			// Get a new instance and set it
			self::$webInstance = new WebOutput();

			// Get the content type
			$contentType = self::$webInstance->getConfigInstance()->getConfigEntry('web_content_type');

			// Set the content type
			if (!empty($contentType)) {
				// Set the header
				$applicationInstance->getResponseInstance()->addHeader('Content-type', $contentType);
			} // END - if
		} // END - if

		// Return instance
		return self::$webInstance;
	}

	/**
	 * Output the code
	 *
	 * @return	void
	 */
	public final function output ($outStream = false) {
		print(stripslashes($outStream));
	}
}

// [EOF]
?>
